EPUBPreferences class

Constructors

EPUBPreferences({required String fontFamily, required int fontSize, required double? fontWeight, required bool? verticalScroll, required Color? backgroundColor, required Color? textColor, double? pageMargins})
EPUBPreferences.fromJsonMap(Map<String, dynamic> map)
factory

Properties

backgroundColor Color?
getter/setter pair
fontFamily String
getter/setter pair
fontSize int
getter/setter pair
fontWeight double?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
pageMargins double?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
textColor Color?
getter/setter pair
verticalScroll bool?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited