loadPublication method

Future<Publication> loadPublication(
  1. String pubUrl
)

Load publication manifest from URL, which is usually a packaged ebook or direct URL to a manifest. This will NOT store a reference to the Publication and is purely meant to be used for fetching metadata/manifest for multiple books.

Implementation

Future<Publication> loadPublication(String pubUrl) =>
    throw UnimplementedError(
      'loadPublication(pubUrl) has not been implemented.',
    );