An interface for classes that can be serialized to JSON.
Subclasses must implement toJson and a static fromJSON method.
As well as a JsonConverter.
- Implementers
- Acquisition
- Availability
- Collection
- Copies
- DomRange
- EncryptedProperties
- Encryption
- Facet
- Feed
- Group
- Holds
- Link
- LocalizedString
- Locations
- Locator
- LocatorText
- Metadata
- MetdataMediaOverlay
- OpdsMetadata
- OpdsPublication
- Point
- PositionsList
- Presentation
- Price
- Properties
- Publication
- PublicationCollection
- ReadiumTtsVoice
- Subject
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Serializes the object to its JSON representation.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited