ReaderTTSVoice class

Constructors

ReaderTTSVoice({required String identifier, required String name, required String language, required bool networkRequired, required TTSVoiceGender gender, required TTSVoiceQuality? quality})
ReaderTTSVoice.fromJson(String jsonStr)
factory
ReaderTTSVoice.fromJsonMap(Map<String, dynamic> map)
factory

Properties

gender TTSVoiceGender
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
identifier String
getter/setter pair
language String
getter/setter pair
name String
getter/setter pair
networkRequired bool
getter/setter pair
quality TTSVoiceQuality?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited