TTSPreferences class

Constructors

TTSPreferences({double? speed, double? pitch, String? voiceIdentifier, String? languageOverride, ControlPanelInfoType? controlPanelInfoType})

Properties

controlPanelInfoType ControlPanelInfoType?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
languageOverride String?
getter/setter pair
pitch double?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
speed double?
getter/setter pair
voiceIdentifier String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited