flureadium_platform_interface library
Classes
- Acquisition
- OPDS Acquisition Object.
- AcquisitionJsonConverter
- AcquisitionLink
- AdditionalProperties
- AudioPreferences
- Availability
- Indicated the availability of a given resource.
- AvailabilityJsonConverter
- AvailabilityState
- Charset
- Charsets
- Collection
- Contributor Object for the Readium Web Publication Manifest. https://readium.org/webpub-manifest/schema/contributor-object.schema.json
- CollectionJsonConverter
- Contributor
- Contributor Object for the Readium Web Publication Manifest. https://readium.org/webpub-manifest/schema/contributor-object.schema.json
- ContributorJsonConverter
- Copies
- Library-specific feature that contains information about the copies that a library has acquired.
- CopiesJsonConverter
- DomRange
- This construct enables a serializable representation of a DOM Range.
- DomRangeJsonConverter
- Drm
- EncryptedProperties
- Encryption
- Indicates that a resource is encrypted/obfuscated and provides relevant information for decryption.
- EncryptionJsonConverter
- EpubLayout
- Hints how the layout of the resource should be presented.
- EPUBPreferences
- Facet
- FacetJsonConverter
- Feed
- FeedJsonConverter
- FlureadiumPlatform
- The interface that implementations of Flureadium must implement.
- Group
- GroupJsonConverter
- Holds
- Library-specific features when a specific book is unavailable but provides a hold list.
- HoldsJsonConverter
- Href
- Represents an HREF, optionally relative to another one.
- JSONable
-
An interface for classes that can be serialized to JSON.
Subclasses must implement toJson and a static
fromJSONmethod. As well as a JsonConverter. - Link
- Link to a resource, either relative to a Publication or external (remote).
- LinkJsonConverter
- LinkListJsonConverter
- LocalizedString
- A potentially localized (multilingual) string.
- LocalizedStringJsonConverter
- Locations
- One or more alternative expressions of the location. https://github.com/readium/architecture/tree/master/models/locators#the-location-object https://github.com/readium/architecture/blob/master/models/locators/extensions/html.md
- LocationsJsonConverter
- Locator
- Provides a precise location in a publication in a format that can be stored and shared.
- LocatorJsonConverter
- LocatorText
- Textual context of the locator.
- LocatorTextJsonConverter
- MediaType
- Represents a document format, identified by a unique RFC 6838 media type.
- Metadata
- https://readium.org/webpub-manifest/schema/metadata.schema.json
- MetadataJsonConverter
- MetdataMediaOverlay
- OpdsMetadata
- OpdsMetadataJsonConverter
- OpdsPublication
- OpdsPublicationJsonConverter
- PDFPreferences
- PDF reader preferences for Flureadium.
- Point
- A serializable representation of a boundary point in a DOM Range.
- PointJsonConverter
- PositionsList
- Readium's positions list: see https://github.com/readium/architecture/tree/master/models/locators/positions
- Presentation
- The Presentation Hints extension defines a number of hints for User Agents about the way content should be presented to the user.
- PresentationFit
- Suggested method for constraining a resource inside the viewport.
- PresentationJsonConverter
- PresentationOrientation
- Suggested orientation for the device when displaying the linked resource.
- PresentationOverflow
- Suggested method for handling overflow while displaying the linked resource.
- PresentationPage
- Indicates how the linked resource should be displayed in a reading environment that displays synthetic spreads.
- PresentationSpread
- Indicates the condition to be met for the linked resource to be rendered within a synthetic spread.
- Price
- The price of a publication in an OPDS link.
- PriceJsonConverter
- Properties
- Set of properties associated with a Link.
- PropertiesJsonConverter
- Publication
- Represents a Readium Web Publication Manifest (RWPM).
- PublicationCollection
- Core Collection Model
- PublicationCollectionJsonConverter
- PublicationFormat
- Format of the Publication file.
- PublicationJsonConverter
- JSON converter for Publication objects.
- QueryParameter
- R2Log
- ReaderDecoration
- ReaderDecorationStyle
- ReaderTTSVoice
- ReaderTTSVoiceNames
- ReadingProgression
- Direction of the Publication reading progression.
- ReadiumReaderWidgetInterface
- ReadiumTimebasedState
- ReadiumTtsVoice
- ReadiumTtsVoicesJsonConverter
- RuntimePlatform
- Subject
- Subject of a Publication.
- SubjectJsonConverter
- TimeFragment
- Translation
- TTSPreferences
- UriTemplate
- A lightweight implementation of URI Template (RFC 6570).
Enums
- ControlPanelInfoType
- DecorationStyle
- OpeningReadiumExceptionType
- PDFFit
- How a PDF page fits within the viewport.
- PDFPageLayout
- Page layout mode for PDF display.
- PDFScrollMode
- Scroll direction for PDF navigation.
- PublicationFormatEnum
- ReadiumHighlightMode
- ReadiumReaderStatus
- Indicates the current reader widget status.
- TimebasedState
- TTSVoiceGender
- TTSVoiceQuality
Extensions
- ContributorExtension on Contributor
- DoubleCheck on double?
- EncryptionPropertiesExtension on Properties
- EpubMetadataExtension on Metadata
- HTMLLocationsExtension on Locations
- IntCheck on int?
-
IterableJSONableExtension
on Iterable<
JSONable> -
LinkListExtension
on List<
Link> - LinkLocator on Link
- ListExtension on List?
- LocationExtension on Locations
-
MapExtension
on Map<
String, dynamic> ? - OpdsPropertiesExtension on Properties
- OpdsPublicationExtension on Publication
- PlatformExceptionCodeExtension on PlatformException
- PresentionMetadataExtension on Metadata
- PresentionPropertiesExtension on Properties
- PublicationLists on Publication
-
QueryParameterExtension
on List<
QueryParameter> - ReadiumColorExtension on Color
- ReadiumColorExtensionNullable on Color?
- ReadiumDurationExtension on Duration
- ReadiumReaderStatusExtension on ReadiumReaderStatus
- ReadiumStringExtension on String
- ReadiumTtsVoiceExtension on ReadiumTtsVoice
- StringExtension on String
- StringHashExtension on String
- StringPathExtension on String
- Extension to extract file extension from a path string.
-
SubcollectionMap
on Map<
String, List< PublicationCollection> > - Take on T
- UriExtension on Uri
Constants
- linkHrefNormalizerIdentity → const LinkHrefNormalizer
- Default href normalizer for Link, doing nothing.
Typedefs
- LinkHrefNormalizer = String Function(String)
- Function used to recursively transform the href of a Link when parsing its JSON representation.